Signal processing
=================

Methods for processing and analyzing fNIRS signals, including
preprocessing, quality control, and feature extraction.

.. autosummary::
   :toctree: _autosummary_sigproc
   :nosignatures:
   :recursive:

   cedalion.nirs
   cedalion.sigproc.epochs
   cedalion.sigproc.frequency
   cedalion.sigproc.motion_correct
   cedalion.sigproc.quality
   cedalion.sigproc.physio


Examples
--------

.. nbgallery::
   :glob:

   ../examples/signal_quality/*
   ../examples/physio/*